==> yaml-validator-0.1.0.tgz: package/validator.js <==
/**
 * The Validation entry point.
 * Determines which version of the schema is being validated and chooses an implementation accordingly
 */

'use strict';

//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

const fs   = require('fs');
const path = require('path');

class Validator {

    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------

    /**
     * Validates a model of the deserialized YAML
     *
     * @param objectModel Deserialized YAML
     * @throws An error containing the details of the validation failure
     */
    static validate(objectModel) {
        const defaultVersion = '1.0';

        let modelVersion = objectModel.version;
        if (!modelVersion) {
            modelVersion = defaultVersion;
        }

        const validatorPath = path.join(__dirname, 'schema', modelVersion, 'validator');
        if (!fs.existsSync(`${validatorPath}.js`)) {
            throw new Error(`Unable to find a validator for schema version ${modelVersion}`);
        }
        const VersionedValidator = require(validatorPath); // eslint-disable-line
        if (!VersionedValidator) {
            throw new Error(`Unable to find a validator for schema version ${modelVersion}`);
        }

        return VersionedValidator(objectModel);
    }
}
// Exported objects/methods
module.exports = Validator.validate;

==> yaml-validator-0.3.0.tgz: package/validator.js <==
/**
 * The Validation entry point.
 * Determines which version of the schema is being validated and chooses an implementation accordingly
 */

'use strict';

//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

const fs   = require('fs');
const path = require('path');

class Validator {

    //------------------------------------------------------------------------------
    // Public Interface
    //------------------------------------------------------------------------------

    /**
     * Validates a model of the deserialized YAML
     *
     * @param objectModel Deserialized YAML
     * @throws An error containing the details of the validation failure
     */
    static validate(objectModel, outputFormat, yaml) {
        const defaultVersion = '1.0';

        let modelVersion = objectModel.version;
        if (!modelVersion) {
            modelVersion = defaultVersion;
        }

        const validatorPath = path.join(__dirname, 'schema', modelVersion, 'validator');
        if (!fs.existsSync(`${validatorPath}.js`)) {
            throw new Error(`Unable to find a validator for schema version ${modelVersion}`);
        }
        const VersionedValidator = require(validatorPath); // eslint-disable-line
        if (!VersionedValidator) {
            throw new Error(`Unable to find a validator for schema version ${modelVersion}`);
        }

        return VersionedValidator(objectModel, outputFormat, yaml);
    }
}
// Exported objects/methods
module.exports = Validator.validate;
